Welcome to RLAI. To launch a live graphical interface to the RLAI package, click below:

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/MatthewGerber/rlai/HEAD?urlpath=lab/tree/jupyter/trainer.ipynb)

Please see the [project website](https://matthewgerber.github.io/rlai/) for more information.

Status:
* PyPI distribution:  ![Python package](https://github.com/MatthewGerber/rlai/workflows/Python%20package/badge.svg)
* Tests:  [![Coverage Status](https://coveralls.io/repos/github/MatthewGerber/rlai/badge.svg?branch=master)](https://coveralls.io/github/MatthewGerber/rlai?branch=master)
